/*
 * This software was developed at the National Institute of Standards and Technology
 * by employees of the Federal Government in the course of their official duties.
 * Pursuant to Title 17 Section 105 of the United States Code this software is not
 * subject to copyright protection within the United States and is in the public domain.
 * The software is an experimental system. NIST assumes no responsibility whatsoever for
 * its use by any party.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS." YOU ACCEPT THE SOFTWARE "AS IS" AND ACKNOWLEDGE
 * THAT NIST MAKES NO WARRANTY OF ANY KIND, EXPRESS, IMPLIED OR STATUTORY, INCLUDING,
 * WITHOUT LIMITATION, THE IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, NON-INFRINGEMENT AND DATA ACCURACY. NIST DOES NOT REPRESENT OR WARRANT THAT
 * THE OPERATION OF THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE, OR THAT ANY
 * DEFECTS WILL BE CORRECTED. NIST DOES NOT WARRANT OR MAKE ANY REPRESENTATIONS
 * REGARDING THE USE OF THE SOFTWARE OR THE RESULTS THEREOF, INCLUDING BUT NOT LIMITED
 * TO THE CORRECTNESS, ACCURACY, RELIABILITY, OR USEFULNESS OF THE SOFTWARE.
 * 
 * You may freely use, copy or distribute this software.Please include appropriate
 * attribution.
 */

package com.simfill;

import java.lang.Thread;
import java.io.FileInputStream;
import java.io.File;

import org.xml.sax.InputSource;
import org.xml.sax.XMLReader;
import org.xml.sax.helpers.XMLReaderFactory;

public class FillingThread extends Thread
{
	public FillingThread( File cardFile, File dataFile )
	{
		m_cardFile = cardFile;
		m_dataFile = dataFile;
	}
	
	public void run()
	{
		try
		{
			// Create the XML parser
			XMLReader xmlParser = XMLReaderFactory.createXMLReader();

			// Parse the card data (PIN codes...)
			LogManager.getInstance().log( "info", "Loading card data...", true );
			CardXmlHandler cardHandler = new CardXmlHandler();
			xmlParser.setContentHandler( cardHandler );
			xmlParser.parse( new InputSource( new FileInputStream( m_cardFile ) ) );
			LogManager.getInstance().log( "info", "Card data loaded.", true );
			
			// Parse the test data and store it on the SIM card
			DataXmlHandler dataHandler = new DataXmlHandler();
			xmlParser.setContentHandler( dataHandler );
			xmlParser.parse( new InputSource( new FileInputStream( m_dataFile ) ) );
		}
		catch( Exception e )
		{
			LogManager.getInstance().log( "excp", e, true );
		}
	}
	
	private File m_cardFile, m_dataFile;
}
