/*
 * This software was developed at the National Institute of Standards and Technology
 * by employees of the Federal Government in the course of their official duties.
 * Pursuant to Title 17 Section 105 of the United States Code this software is not
 * subject to copyright protection within the United States and is in the public domain.
 * The software is an experimental system. NIST assumes no responsibility whatsoever for
 * its use by any party.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS." YOU ACCEPT THE SOFTWARE "AS IS" AND ACKNOWLEDGE
 * THAT NIST MAKES NO WARRANTY OF ANY KIND, EXPRESS, IMPLIED OR STATUTORY, INCLUDING,
 * WITHOUT LIMITATION, THE IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, NON-INFRINGEMENT AND DATA ACCURACY. NIST DOES NOT REPRESENT OR WARRANT THAT
 * THE OPERATION OF THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE, OR THAT ANY
 * DEFECTS WILL BE CORRECTED. NIST DOES NOT WARRANT OR MAKE ANY REPRESENTATIONS
 * REGARDING THE USE OF THE SOFTWARE OR THE RESULTS THEREOF, INCLUDING BUT NOT LIMITED
 * TO THE CORRECTNESS, ACCURACY, RELIABILITY, OR USEFULNESS OF THE SOFTWARE.
 * 
 * You may freely use, copy or distribute this software.Please include appropriate
 * attribution.
 */

package com.simfill.gsm;

import com.jaccal.util.NumUtil;
import com.simfill.Registry;

// Stores the IMSI data to be stored in EF_IMSI
public class AD extends TransparentFile
{
	public static final byte AD_OPMOD_NORMAL        = ( byte )0x00;
	public static final byte AD_OPMOD_TYPEAPPROVAL  = ( byte )0x80;
	public static final byte AD_OPMOD_MASK_SPECIFIC = ( byte )0x01;
	public static final byte AD_OPMOD_MAINTENANCE   = ( byte )0x02;
	public static final byte AD_OPMOD_CELLTEST      = ( byte )0x04;
	
	public static final short AD_INFO_OFM_DISABLED	= ( short )0x00;
	public static final short AD_INFO_OFM_ACTIVATED	= ( short )0x01;
	
	public AD( int size ) throws Exception
	{
		super( size );
		
		if( getSize() < 3 )
		{
			throw new Exception( "AD: the size of the file EF_AD is not standard." );
		}
		
		setAddInfo( ( short )0 );
	}

	public void setOpMode( byte opmode ) throws Exception
	{
		m_opmode = opmode;
	}
	
	public void setAddInfo( short info )
	{
		m_info = info;
	}
	
	public short getAddInfo()
	{
		return m_info;
	}
	
	public void setMNCLength( byte length ) throws Exception
	{
		if( length != 2 && length != 3 )
		{
			throw new Exception( "AD: MNC length in IMSI should be 2 or 3, not " + Byte.toString( length ) );
		}

		m_mncLength = length;
	}
	
	public String toHex()
	{
		byte [] storage = new byte[ getSize() ];
		
		switch( getSize() )
		{
			default:
				
				for( int idx = 4; idx < getSize(); ++idx )
				{
					storage[ idx ] = ( byte )0xff; 
				}
				// no break here
		
			case 4:

				storage[ 3 ] = m_mncLength;
				// no break here
				
			case 3:
		
				storage[ 0 ] = m_opmode;
				storage[ 1 ] = ( byte )( ( m_info & 0xff00 ) >> 8 );
				storage[ 2 ] = ( byte )( ( m_info & 0x00ff ) >> 0 );
		}
		
		return NumUtil.hex2String( storage );
	}
	
	public String toString()
	{
		StringBuilder storage = new StringBuilder();
		String newline = Registry.getInstance().get( "report.newline" );

		storage.append( "Operation mode: " );
		switch( m_opmode )
		{
			case AD_OPMOD_NORMAL:
				storage.append( "normal" );
				break;
			case AD_OPMOD_TYPEAPPROVAL:
				storage.append( "type approval" );
				break;
			case AD_OPMOD_NORMAL		| AD_OPMOD_MASK_SPECIFIC:
				storage.append( "normal + specific facilities" );
				break;
			case AD_OPMOD_TYPEAPPROVAL	| AD_OPMOD_MASK_SPECIFIC:
				storage.append( "type approval + specific facilities" );
				break;
			case AD_OPMOD_MAINTENANCE:
				storage.append( "maintenance (offline)" );
				break;
			case AD_OPMOD_CELLTEST:
				storage.append( "cell test" );
				break;
		}
		storage.append( newline );
		
		storage.append( "Additional info: " );
		storage.append( newline );
		if( ( m_info & AD_INFO_OFM_ACTIVATED ) != 0 )
		{
			storage.append( " - OFM to be activated by the ME" );
		}
		else
		{
			storage.append( " - OFM to be disabled by the ME" );
		}
		storage.append( newline );
		
		if( getSize() >= 4 )
		{
			storage.append( "Length of MNC in IMSI: " );
			storage.append( m_mncLength );
			storage.append( newline );
		}
		
		return storage.toString();
	}

	// MS operation mode
	private byte m_opmode;
	
	// Additional information
	private short m_info;
	
	// Length of MNC in IMSI
	private byte m_mncLength;
}
