/*
 * This software was developed at the National Institute of Standards and Technology
 * by employees of the Federal Government in the course of their official duties.
 * Pursuant to Title 17 Section 105 of the United States Code this software is not
 * subject to copyright protection within the United States and is in the public domain.
 * The software is an experimental system. NIST assumes no responsibility whatsoever for
 * its use by any party.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS." YOU ACCEPT THE SOFTWARE "AS IS" AND ACKNOWLEDGE
 * THAT NIST MAKES NO WARRANTY OF ANY KIND, EXPRESS, IMPLIED OR STATUTORY, INCLUDING,
 * WITHOUT LIMITATION, THE IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, NON-INFRINGEMENT AND DATA ACCURACY. NIST DOES NOT REPRESENT OR WARRANT THAT
 * THE OPERATION OF THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE, OR THAT ANY
 * DEFECTS WILL BE CORRECTED. NIST DOES NOT WARRANT OR MAKE ANY REPRESENTATIONS
 * REGARDING THE USE OF THE SOFTWARE OR THE RESULTS THEREOF, INCLUDING BUT NOT LIMITED
 * TO THE CORRECTNESS, ACCURACY, RELIABILITY, OR USEFULNESS OF THE SOFTWARE.
 * 
 * You may freely use, copy or distribute this software.Please include appropriate
 * attribution.
 */

package com.simfill.gsm;

import com.jaccal.util.NumUtil;

// Storage for information on SIM's files
public class FileInfo
{
	public FileInfo( byte [] status )
	{
		if( status == null || status.length < 13 ) return;

		m_size = ( ( status[ 2 ] & 0x000000ff ) << 8 ) + ( status[ 3 ]& 0x000000ff );
		m_fid  = ( ( status[ 4 ] & 0x000000ff ) << 8 ) + ( status[ 5 ]& 0x000000ff );
		m_sid = NumUtil.int2HexString( m_fid ).substring( 4, 8 );
		m_type = status[ 6 ];
//		Not used
//		m_increaseAllowed = status[ 7 ];
//		m_valid = status[ 11 ];
		m_xSize = ( short )( status[ 12 ] & 0x000000ff );

		if( status.length != m_xSize + 13 ) return;

		switch( m_type )
		{
			case FILETYPE_EF:
				m_struct  = status[ 13 ];
				m_recSize = ( short )( status[ 14 ] & 0x000000ff );
				break;
		}
	}
	
	public int		getSize()		{ return m_size;	}
	public int		getFID()		{ return m_fid;		}
	public String	getSID()		{ return m_sid;		}
	public byte		getType()		{ return m_type;	}
	public byte		getStruct()		{ return m_struct;	}
	public short	getRecSize()	{ return m_recSize;	}
	
	public static final byte FILETYPE_RFU = 0;
	public static final byte FILETYPE_MF  = 1;
	public static final byte FILETYPE_DF  = 2;
	public static final byte FILETYPE_EF  = 4;
	
	public static final byte STRUCT_TRANSPARENT = 0;
	public static final byte STRUCT_LINEARFIXED = 1;
	public static final byte STRUCT_CYCLIC      = 3;

	private int    m_size;
	private int    m_fid;
	private String m_sid;
	private byte   m_type; // 0 = RFU, 1 = MF, 2 = DF, 4 = EF
//	Not used
//	private byte   m_increaseAllowed;
//	private byte   m_valid; 
	private short  m_xSize;
	private byte   m_struct; // 0 = transparent, 1 = linear fixed, 3 = cyclic
	private short  m_recSize;
}
