/*
 * This software was developed at the National Institute of Standards and Technology
 * by employees of the Federal Government in the course of their official duties.
 * Pursuant to Title 17 Section 105 of the United States Code this software is not
 * subject to copyright protection within the United States and is in the public domain.
 * The software is an experimental system. NIST assumes no responsibility whatsoever for
 * its use by any party.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS." YOU ACCEPT THE SOFTWARE "AS IS" AND ACKNOWLEDGE
 * THAT NIST MAKES NO WARRANTY OF ANY KIND, EXPRESS, IMPLIED OR STATUTORY, INCLUDING,
 * WITHOUT LIMITATION, THE IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, NON-INFRINGEMENT AND DATA ACCURACY. NIST DOES NOT REPRESENT OR WARRANT THAT
 * THE OPERATION OF THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE, OR THAT ANY
 * DEFECTS WILL BE CORRECTED. NIST DOES NOT WARRANT OR MAKE ANY REPRESENTATIONS
 * REGARDING THE USE OF THE SOFTWARE OR THE RESULTS THEREOF, INCLUDING BUT NOT LIMITED
 * TO THE CORRECTNESS, ACCURACY, RELIABILITY, OR USEFULNESS OF THE SOFTWARE.
 * 
 * You may freely use, copy or distribute this software.Please include appropriate
 * attribution.
 */

package com.simfill.gsm;

import com.simfill.Registry;

// Stores the IMSI data to be stored in EF_IMSI
public class IMSI extends TransparentFile
{
	public IMSI( int size ) throws Exception
	{
		super( size );
		
		if( getSize() != 9 )
		{
			throw new Exception( "IMSI: the size of the file EF_IMSI is not standard." );
		}
	}

	public void setIMSI( String imsi ) throws Exception
	{
		if( imsi.length() > 15 )
		{
			throw new Exception( "IMSI: the size of the IMSI should be less than 15 digits." );
		}

		m_imsi = imsi;
		
		int length = imsi.length() + 1; // +1 is for the prepended '9' - see 3GPP TS 11.11 section 10.3.2
		
		m_length = ( byte )( ( length >> 1 ) + ( length & 1 ) );
	}

	public String toHex()
	{
		StringBuilder storage = new StringBuilder();
		
		String padded = ( '9' + m_imsi + "ffffffffffffffff" ).substring( 0, 16 );
		
		// Store the effective length of the IMSI
		// Note: the length is 8 or less, so it fits
		// in the lowest 4 bits of the first byte
		storage.append( '0' );
		storage.append( m_length );
		
		// Store the actual IMSI
		for( int it = 0; it < 16; it += 2 )
		{
			storage.append( padded.charAt( it + 1 ) );
			storage.append( padded.charAt( it + 0 ) );
		}
		
		return storage.toString();
	}
	
	public String toString()
	{
		return "IMSI: " + m_imsi + Registry.getInstance().get( "report.newline" );
	}

	// IMSI
	private String m_imsi;
	
	// Significant length of IMSI
	private byte m_length;
}
