/*
 * This software was developed at the National Institute of Standards and Technology
 * by employees of the Federal Government in the course of their official duties.
 * Pursuant to Title 17 Section 105 of the United States Code this software is not
 * subject to copyright protection within the United States and is in the public domain.
 * The software is an experimental system. NIST assumes no responsibility whatsoever for
 * its use by any party.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS." YOU ACCEPT THE SOFTWARE "AS IS" AND ACKNOWLEDGE
 * THAT NIST MAKES NO WARRANTY OF ANY KIND, EXPRESS, IMPLIED OR STATUTORY, INCLUDING,
 * WITHOUT LIMITATION, THE IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, NON-INFRINGEMENT AND DATA ACCURACY. NIST DOES NOT REPRESENT OR WARRANT THAT
 * THE OPERATION OF THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE, OR THAT ANY
 * DEFECTS WILL BE CORRECTED. NIST DOES NOT WARRANT OR MAKE ANY REPRESENTATIONS
 * REGARDING THE USE OF THE SOFTWARE OR THE RESULTS THEREOF, INCLUDING BUT NOT LIMITED
 * TO THE CORRECTNESS, ACCURACY, RELIABILITY, OR USEFULNESS OF THE SOFTWARE.
 * 
 * You may freely use, copy or distribute this software.Please include appropriate
 * attribution.
 */

package com.simfill;

import org.xml.sax.helpers.DefaultHandler;
import org.xml.sax.Attributes;
import org.xml.sax.SAXException;

import java.util.Stack;

public class CardXmlHandler extends DefaultHandler
{
	public CardXmlHandler()
	{
		super();

		m_state = new Stack< State >();
		m_state.push( State.INITIALIZED );
		
		m_data = new StringBuilder();
	}

	public void startElement( String uri, String localName, String qName, Attributes attributes )
	{
		m_data.delete( 0, m_data.length() );

		switch( m_state.peek() )
		{
			case INITIALIZED:
				
				// Reset the registry keys in case they have been previously set
				Registry r = Registry.getInstance();
				r.remove( "card.pin1" );
				r.remove( "card.pin2" );
				r.remove( "card.type" );
				r.remove( "card.axalto.key" );
				r.remove( "card.axalto.keyRefId" );
				r.remove( "card.gemplus.adm1" );

				if( localName.equals( "card" ) ) m_state.push( State.CARD );
				break;

			case CARD:

				     if( localName.equals( "pin1"      ) )	m_state.push( State.PIN1    );
				else if( localName.equals( "pin2"      ) )	m_state.push( State.PIN2    );
				else if( localName.equals( "usimera3"  ) )	m_state.push( State.USIMERA3  );
				else if( localName.equals( "gemxplore" ) )	m_state.push( State.GEMXPLORE );
				break;
				
			case USIMERA3:
				
				     if( localName.equals( "key"      ) )	m_state.push( State.USIMERA3_PARSING_KEY      );
				else if( localName.equals( "keyrefid" ) )	m_state.push( State.USIMERA3_PARSING_KEYREFID );
				break;
				
			case GEMXPLORE:
				
				if( localName.equals( "adm1" ) )			m_state.push( State.GEMXPLORE_PARSING_ADM1 );
				break;
		}					
	}

	public void endElement( String uri, String localName, String qName )
	{
		switch( m_state.peek() )
		{
			case CARD:
				
				if( localName.equals( "card" ) ) 
				{
					m_state.pop();
				}
				break;

			case PIN1:

				if( localName.equals( "pin1" ) )
				{
					m_state.pop();
					Registry.getInstance().put( "card.pin1", m_data.toString() );
				}
				break;

			case PIN2:
				
				if( localName.equals( "pin2" ) )
				{
					m_state.pop();
					Registry.getInstance().put( "card.pin2", m_data.toString() );
				}
				break;
				
			case USIMERA3:
				
				if( localName.equals( "usimera3" ) )
				{
					m_state.pop();
					Registry.getInstance().put( "card.type", "usimera3" );
				}
				break;

			case USIMERA3_PARSING_KEY:
				
				if( localName.equals( "key" ) )
				{
					m_state.pop();
					Registry.getInstance().put( "card.axalto.key", m_data.toString() );
				}
				break;
				
			case USIMERA3_PARSING_KEYREFID:
				
				if( localName.equals( "keyrefid" ) )
				{
					m_state.pop();
					Registry.getInstance().put( "card.axalto.keyRefId", m_data.toString() );
				}
				break;

			case GEMXPLORE:
				
				if( localName.equals( "gemxplore" ) )
				{
					m_state.pop();
					Registry.getInstance().put( "card.type", "gemxplore" );
				}
				break;

			case GEMXPLORE_PARSING_ADM1:
				
				if( localName.equals( "adm1" ) )
				{
					m_state.pop();
					Registry.getInstance().put( "card.gemplus.adm1", m_data.toString() );
				}
				break;
		}
	}

	public void characters( char[] ch, int start, int length ) throws SAXException
	{
		switch( m_state.peek() )
		{
			case PIN1:
			case PIN2:
			case USIMERA3_PARSING_KEY:
			case USIMERA3_PARSING_KEYREFID:
			case GEMXPLORE_PARSING_ADM1:

				m_data.append( ch, start, length );
				break;
		}
	}
	
	// Current state of the parser
	private enum State
	{
		INITIALIZED,
		CARD,
		
		PIN1,
		PIN2,
		
		USIMERA3,
		USIMERA3_PARSING_KEY,
		USIMERA3_PARSING_KEYREFID,
		
		GEMXPLORE,
		GEMXPLORE_PARSING_ADM1
	}

	// Stack used to store the states of the parser
	private Stack< State > m_state;
	
	// Storage for the data being parsed
	private StringBuilder m_data;
}
