/*
 * This software was developed at the National Institute of Standards and Technology
 * by employees of the Federal Government in the course of their official duties.
 * Pursuant to Title 17 Section 105 of the United States Code this software is not
 * subject to copyright protection within the United States and is in the public domain.
 * The software is an experimental system. NIST assumes no responsibility whatsoever for
 * its use by any party.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS." YOU ACCEPT THE SOFTWARE "AS IS" AND ACKNOWLEDGE
 * THAT NIST MAKES NO WARRANTY OF ANY KIND, EXPRESS, IMPLIED OR STATUTORY, INCLUDING,
 * WITHOUT LIMITATION, THE IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, NON-INFRINGEMENT AND DATA ACCURACY. NIST DOES NOT REPRESENT OR WARRANT THAT
 * THE OPERATION OF THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE, OR THAT ANY
 * DEFECTS WILL BE CORRECTED. NIST DOES NOT WARRANT OR MAKE ANY REPRESENTATIONS
 * REGARDING THE USE OF THE SOFTWARE OR THE RESULTS THEREOF, INCLUDING BUT NOT LIMITED
 * TO THE CORRECTNESS, ACCURACY, RELIABILITY, OR USEFULNESS OF THE SOFTWARE.
 * 
 * You may freely use, copy or distribute this software.Please include appropriate
 * attribution.
 */

package com.simfill.gsm;

import java.lang.String;

import com.simfill.LogManager;

// SMS default 7-bit coded alphabet
public class Charset
{
	public static final byte CHARSET_ESCAPE = 0x1b;
	
	public static byte [] translate( String s )
	{
		int idx = 0;
		byte [] storage = new byte[ getStringLength( s ) ];
		
		for( char c : s.toCharArray() )
		{
			int tc = translate( c );
			if( tc < 256 )
			{
				storage[ idx++ ] = ( byte )tc;
			}
			else
			{
				storage[ idx++ ] = ( byte )( tc >> 8 );
				storage[ idx++ ] = ( byte )( tc & 0xff );
			}
		}

		return storage;
	}
	
	public static String untranslate( byte [] ts, int index, int size )
	{
		StringBuffer s = new StringBuffer();
		
		for( int idx = index; idx < index + size; ++idx )
		{
			switch( ts[ idx ] )
			{
				case CHARSET_ESCAPE:
					switch( ts[ ++idx ] )
					{
						case 0x14: s.append( '^' );  break;
						case 0x28: s.append( '{' );  break;
						case 0x29: s.append( '}' );  break;
						case 0x2f: s.append( '\\' ); break;
						case 0x3c: s.append( '[' );  break;
						case 0x3d: s.append( '~' );  break;
						case 0x3e: s.append( ']' );  break;
						case 0x50: s.append( '|' );  break;
						case 0x65: s.append( '' );  break;
					}
					break;
				
				case -1:
					// FIXME
					LogManager.getInstance().log( "err", "0xff spotted", true );
					break;
					
					default:
						s.append( m_alphabet.charAt( ts[ idx ] ) );
			}
		}
		
		return s.toString();
	}

	private static int translate( char c )
	{
		switch( c )
		{
			case '^':  return 0x1b14;
			case '{':  return 0x1b28;
			case '}':  return 0x1b29;
			case '\\': return 0x1b2f;
			case '[':  return 0x1b3c;
			case '~':  return 0x1b3d;
			case ']':  return 0x1b3e;
			case '|':  return 0x1b40;
			case '':  return 0x1b65;
			default:   return m_alphabet.indexOf( c );
		}
	}

	private static int getStringLength( String s )
	{
		int length = 0;

		for( char c : s.toCharArray() )
		{
			switch( c )
			{
				case '^':
				case '{':
				case '}':
				case '\\':
				case '[':
				case '~':
				case ']':
				case '|':
				case '':
					length++;
				default:
					length++;
			}
		}

		return length;
	}

	// FIXME: some greek characters have been replaced by '~'
	private static final String m_alphabet = "@$\r\n~_~~~~~~~~~` !\"#%&'()*+,-./0123456789:;<=>?ABCDEFGHIJKLMNOPQRSTUVWXYZܧabcdefghijklmnopqrstuvwxyz";
}
