/*
 * This software was developed at the National Institute of Standards and Technology
 * by employees of the Federal Government in the course of their official duties.
 * Pursuant to Title 17 Section 105 of the United States Code this software is not
 * subject to copyright protection within the United States and is in the public domain.
 * The software is an experimental system. NIST assumes no responsibility whatsoever for
 * its use by any party.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS." YOU ACCEPT THE SOFTWARE "AS IS" AND ACKNOWLEDGE
 * THAT NIST MAKES NO WARRANTY OF ANY KIND, EXPRESS, IMPLIED OR STATUTORY, INCLUDING,
 * WITHOUT LIMITATION, THE IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, NON-INFRINGEMENT AND DATA ACCURACY. NIST DOES NOT REPRESENT OR WARRANT THAT
 * THE OPERATION OF THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE, OR THAT ANY
 * DEFECTS WILL BE CORRECTED. NIST DOES NOT WARRANT OR MAKE ANY REPRESENTATIONS
 * REGARDING THE USE OF THE SOFTWARE OR THE RESULTS THEREOF, INCLUDING BUT NOT LIMITED
 * TO THE CORRECTNESS, ACCURACY, RELIABILITY, OR USEFULNESS OF THE SOFTWARE.
 * 
 * You may freely use, copy or distribute this software.Please include appropriate
 * attribution.
 */

package com.simfill.gsm;

import com.jaccal.util.NumUtil;
import com.simfill.LogManager;
import com.simfill.Registry;

import java.lang.StringBuffer;

// Stores the data to be stored in EF_LP
public class LP extends TransparentFile
{
	// Langages as specified in GSM TS 03.38 / 3GPP TS 23.038
	public static final byte LANG_GERMAN      = 0x00;
	public static final byte LANG_ENGLISH     = 0x01;
	public static final byte LANG_ITALIAN     = 0x02;
	public static final byte LANG_FRENCH      = 0x03;
	public static final byte LANG_SPANISH     = 0x04;
	public static final byte LANG_DUTCH       = 0x05;
	public static final byte LANG_SWEDISH     = 0x06;
	public static final byte LANG_DANISH      = 0x07;
	public static final byte LANG_PORTUGUESE  = 0x08;
	public static final byte LANG_FINNISH     = 0x09;
	public static final byte LANG_NORWEGIAN   = 0x0a;
	public static final byte LANG_GREEK       = 0x0b;
	public static final byte LANG_TURKISH     = 0x0c;
	public static final byte LANG_HUNGARIAN   = 0x0d;
	public static final byte LANG_POLISH      = 0x0e;
	public static final byte LANG_UNSPECIFIED = 0x0f;
	public static final byte LANG_CZECH       = 0x20;
	public static final byte LANG_HEBREW      = 0x21;
	public static final byte LANG_ARABIC      = 0x22;
	public static final byte LANG_RUSSIAN     = 0x23;

	public LP( int size )
	{
		super( size );
		
		m_lang = new byte[ getSize() ];
		
		for( int index = 0; index < size; ++index )
		{
			m_lang[ index ] = ( byte )0xff;
		}
	}
	
	public void setLang( int index, byte lang )
	{
		if( 0 <= index && index < getSize() )
		{
			m_lang[ index ] = lang;
		}
		else
		{
			LogManager.getInstance().log( "warn", "The storage index for the language preference is out of range.", true );
		}
	}

	public String toHex()
	{
		return NumUtil.hex2String( m_lang );
	}
	
	public String toString()
	{
		StringBuffer report = new StringBuffer();
		String newline = Registry.getInstance().get( "report.newline" );

		for( int it = 0; it < m_lang.length; ++it )
		{
			report.append( it + 1 );
			report.append( ": " );

			switch( m_lang[ it ] )
			{
				case LANG_GERMAN:      report.append( "German"      ); break;
				case LANG_ENGLISH:     report.append( "English"     ); break;
				case LANG_ITALIAN:     report.append( "Italian"     ); break;
				case LANG_FRENCH:      report.append( "French"      ); break;
				case LANG_SPANISH:     report.append( "Spanish"     ); break;
				case LANG_DUTCH:       report.append( "Dutch"       ); break;
				case LANG_SWEDISH:     report.append( "Swedish"     ); break;
				case LANG_DANISH:      report.append( "Danish"      ); break;
				case LANG_PORTUGUESE:  report.append( "Portuguese"  ); break;
				case LANG_FINNISH:     report.append( "Finnish"     ); break;
				case LANG_NORWEGIAN:   report.append( "Norwegian"   ); break;
				case LANG_GREEK:       report.append( "Greek"       ); break;
				case LANG_TURKISH:     report.append( "Turkish"     ); break;
				case LANG_HUNGARIAN:   report.append( "Hungarian"   ); break;
				case LANG_POLISH:      report.append( "Polish"      ); break;
				case LANG_UNSPECIFIED: report.append( "Unspecified" ); break;
				case LANG_CZECH:       report.append( "Czech"       ); break;
				case LANG_HEBREW:      report.append( "Hebrew"      ); break;
				case LANG_ARABIC:      report.append( "Arabic"      ); break;
				case LANG_RUSSIAN:     report.append( "Russian"     ); break;
				case ( byte )0xff:     report.append( "(empty)"     ); break;
				default:               report.append( "INVALID"     );
			}
			
			report.append( newline );
		}

		return report.toString();
	}

	// Languages
	private byte [] m_lang;
}
