/*
 * This software was developed at the National Institute of Standards and Technology
 * by employees of the Federal Government in the course of their official duties.
 * Pursuant to Title 17 Section 105 of the United States Code this software is not
 * subject to copyright protection within the United States and is in the public domain.
 * The software is an experimental system. NIST assumes no responsibility whatsoever for
 * its use by any party.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS." YOU ACCEPT THE SOFTWARE "AS IS" AND ACKNOWLEDGE
 * THAT NIST MAKES NO WARRANTY OF ANY KIND, EXPRESS, IMPLIED OR STATUTORY, INCLUDING,
 * WITHOUT LIMITATION, THE IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE, NON-INFRINGEMENT AND DATA ACCURACY. NIST DOES NOT REPRESENT OR WARRANT THAT
 * THE OPERATION OF THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE, OR THAT ANY
 * DEFECTS WILL BE CORRECTED. NIST DOES NOT WARRANT OR MAKE ANY REPRESENTATIONS
 * REGARDING THE USE OF THE SOFTWARE OR THE RESULTS THEREOF, INCLUDING BUT NOT LIMITED
 * TO THE CORRECTNESS, ACCURACY, RELIABILITY, OR USEFULNESS OF THE SOFTWARE.
 * 
 * You may freely use, copy or distribute this software.Please include appropriate
 * attribution.
 */

package com.simfill.gsm;

import com.jaccal.util.NumUtil;

public class SMSUserDataHeaderElement
{
	// Return the size of the element
	public int getSize()
	{
		return m_ied == null ? 2 : m_ied.length + 2;
	}
	
	// Return the data
	public byte [] getData()
	{
		int size = ( m_ied == null ) ? 0 : m_ied.length;
		byte [] data = new byte[ 2 + size ];
		
		data[ 0 ] = ( byte )m_iei;
		data[ 1 ] = ( byte )size;
		
		System.arraycopy( m_ied, 0, data, 2, size );
		
		return data;
	}
	
	// Return a report string
	public String toString()
	{
		StringBuilder storage = new StringBuilder();

		storage.append( "iei=" );
		storage.append( m_iei );
		
		if( m_ied != null )
		{
			storage.append( " size=" );
			storage.append( m_ied.length );
			
			storage.append( " data=" );
			storage.append( NumUtil.hex2String( m_ied ) );
		}
		
		return storage.toString();
	}
	
	// Information Element Identifier (IEI), according to 3GPP TS 23.040
	// FIXME: only a subset of all possible values is supported at the moment
	protected static final int IEI_CONCATENATED  = 0x00;
	protected static final int IEI_LARGE_PICTURE = 0x10;
	protected static final int IEI_SMALL_PICTURE = 0x11;
	
	private int m_iei;
		
	// Information Element Data (IED), according to 3GPP TS 23.040
	private byte [] m_ied;

	// Constructor
	protected SMSUserDataHeaderElement( int iei )
	{
		m_iei = iei;
	}
	
	// Set data
	protected void setData( byte [] data )
	{
		m_ied = data;
	}
}

